<!-- templates/forgot-password.html -->
{% extends 'base.html' %} {% block content %}
<div class="container">
  <div class="row justify-content-center my-5">
    <div class="col-md-6 mx-auto">
      <h2 class="text-center">Forgot Password</h2>

      {% with messages = get_flashed_messages(with_categories=true) %} {% if
      messages %}
      <div class="alert alert-dismissible fade show" role="alert">
        {% for category, message in messages %}
        <div
          class="alert alert-{{ category }} alert-dismissible fade show"
          role="alert"
        >
          {{ message }}
          <button
            type="button"
            class="btn-close"
            data-bs-dismiss="alert"
            aria-label="Close"
          ></button>
        </div>
        {% endfor %}
      </div>
      {% endif %} {% endwith %}

      <form method="POST" class="p-4 border rounded bg-light">
        <div class="mb-3">
          <label for="email" class="form-label">Email address</label>
          <input
            type="email"
            class="form-control"
            id="email"
            name="email"
            placeholder="Enter your email"
            required
          />
        </div>
        <button type="submit" class="btn btn-primary w-100">
          Send Reset Link
        </button>
      </form>
    </div>
  </div>
</div>
{% endblock %}
