<!-- templates/reset-password.html -->
{% extends 'base.html' %} {% block content %}
<h2>Reset Password</h2>
<form method="POST">
  <label>New Password:</label>
  <input type="password" name="password" required />
  <button type="submit">Set New Password</button>
</form>
{% endblock %}
